==> ejc-probuilddiary-impl-3.0.0-20220916.034313-3-sources.jar: com/ejianc/business/probuilddiary/ledger/bean/LedgerInformationEntity.java <==
package com.ejianc.business.probuilddiary.ledger.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.util.Date;

/**
 * 日志台账-工程资料归档及会议情况（资料员）
 *
 * @author baipengyan
 */
@TableName("ejc_probuilddiary_ledger_information")
public class LedgerInformationEntity extends BaseEntity {
	private static final long serialVersionUID = -3880464103242295809L;

	@TableField(value = "person_id")
	private Long personId; // 个人日志id
	@TableField(value = "inform_mold_id")
	private Long informMoldId; // 工作类型id
	@TableField(value = "inform_mold_name")
	private String informMoldName; // 工作类型名称
	@TableField(value = "inform_mold_code")
	private String informMoldCode; // 工作类型编码
	@TableField(value = "information_memo")
	private String informationMemo; // 工作描述
	@TableField(value = "commit_user_id")
	private Long commitUserId; // 提交人id
	@TableField(value = "commit_user_code")
	private String commitUserCode; // 提交人账号
	@TableField(value = "commit_user_name")
	private String commitUserName; // 提交人名称
	@TableField(value = "commit_date")
	private Date commitDate; // 提交日期
	@TableField(value = "project_log_id")
	private Long projectLogId; // 项目日志id
	@TableField(value = "ledger_id")
	private Long ledgerId; // 日志台账id
	@TableField(value = "file_type")
	private String fileType; // 文件类型


	public Long getPersonId() {
		return personId;
	}

	public void setPersonId(Long personId) {
		this.personId = personId;
	}

	public Long getInformMoldId() {
		return informMoldId;
	}

	public void setInformMoldId(Long informMoldId) {
		this.informMoldId = informMoldId;
	}

	public String getInformMoldName() {
		return informMoldName;
	}

	public void setInformMoldName(String informMoldName) {
		this.informMoldName = informMoldName;
	}

	public String getInformMoldCode() {
		return informMoldCode;
	}

	public void setInformMoldCode(String informMoldCode) {
		this.informMoldCode = informMoldCode;
	}

	public String getInformationMemo() {
		return informationMemo;
	}

	public void setInformationMemo(String informationMemo) {
		this.informationMemo = informationMemo;
	}

	public Long getCommitUserId() {
		return commitUserId;
	}

	public void setCommitUserId(Long commitUserId) {
		this.commitUserId = commitUserId;
	}

	public String getCommitUserCode() {
		return commitUserCode;
	}

	public void setCommitUserCode(String commitUserCode) {
		this.commitUserCode = commitUserCode;
	}

	public String getCommitUserName() {
		return commitUserName;
	}

	public void setCommitUserName(String commitUserName) {
		this.commitUserName = commitUserName;
	}

	public Date getCommitDate() {
		return commitDate;
	}

	public void setCommitDate(Date commitDate) {
		this.commitDate = commitDate;
	}

	public Long getProjectLogId() {
		return projectLogId;
	}

	public void setProjectLogId(Long projectLogId) {
		this.projectLogId = projectLogId;
	}

	public Long getLedgerId() {
		return ledgerId;
	}

	public void setLedgerId(Long ledgerId) {
		this.ledgerId = ledgerId;
	}

	public String getFileType() {
		return fileType;
	}

	public void setFileType(String fileType) {
		this.fileType = fileType;
	}
}

==> ejc-probuilddiary-impl-3.0.0-20220923.051842-54-sources.jar: com/ejianc/business/probuilddiary/ledger/bean/LedgerInformationEntity.java <==
package com.ejianc.business.probuilddiary.ledger.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.util.Date;

/**
 * 日志台账-工程资料归档及会议情况（资料员）
 *
 * @author baipengyan
 */
@TableName("ejc_probuilddiary_ledger_information")
public class LedgerInformationEntity extends BaseEntity {
	private static final long serialVersionUID = -3880464103242295809L;

	@TableField(value = "person_id")
	private Long personId; // 个人日志id
	@TableField(value = "inform_mold_id")
	private Long informMoldId; // 工作类型id
	@TableField(value = "inform_mold_name")
	private String informMoldName; // 工作类型名称
	@TableField(value = "inform_mold_code")
	private String informMoldCode; // 工作类型编码
	@TableField(value = "information_memo")
	private String informationMemo; // 工作描述
	@TableField(value = "commit_user_id")
	private Long commitUserId; // 提交人id
	@TableField(value = "commit_user_code")
	private String commitUserCode; // 提交人账号
	@TableField(value = "commit_user_name")
	private String commitUserName; // 提交人名称
	@TableField(value = "commit_date")
	private Date commitDate; // 提交日期
	@TableField(value = "project_log_id")
	private Long projectLogId; // 项目日志id
	@TableField(value = "ledger_id")
	private Long ledgerId; // 日志台账id
	@TableField(value = "file_type")
	private String fileType; // 文件类型
	@TableField(value = "log_number")
	private String logNumber; // 日志项编码
	@TableField(value = "project_manager_flag")
	private Boolean projectManagerFlag; // 项目经理标识


	public Long getPersonId() {
		return personId;
	}

	public void setPersonId(Long personId) {
		this.personId = personId;
	}

	public Long getInformMoldId() {
		return informMoldId;
	}

	public void setInformMoldId(Long informMoldId) {
		this.informMoldId = informMoldId;
	}

	public String getInformMoldName() {
		return informMoldName;
	}

	public void setInformMoldName(String informMoldName) {
		this.informMoldName = informMoldName;
	}

	public String getInformMoldCode() {
		return informMoldCode;
	}

	public void setInformMoldCode(String informMoldCode) {
		this.informMoldCode = informMoldCode;
	}

	public String getInformationMemo() {
		return informationMemo;
	}

	public void setInformationMemo(String informationMemo) {
		this.informationMemo = informationMemo;
	}

	public Long getCommitUserId() {
		return commitUserId;
	}

	public void setCommitUserId(Long commitUserId) {
		this.commitUserId = commitUserId;
	}

	public String getCommitUserCode() {
		return commitUserCode;
	}

	public void setCommitUserCode(String commitUserCode) {
		this.commitUserCode = commitUserCode;
	}

	public String getCommitUserName() {
		return commitUserName;
	}

	public void setCommitUserName(String commitUserName) {
		this.commitUserName = commitUserName;
	}

	public Date getCommitDate() {
		return commitDate;
	}

	public void setCommitDate(Date commitDate) {
		this.commitDate = commitDate;
	}

	public Long getProjectLogId() {
		return projectLogId;
	}

	public void setProjectLogId(Long projectLogId) {
		this.projectLogId = projectLogId;
	}

	public Long getLedgerId() {
		return ledgerId;
	}

	public void setLedgerId(Long ledgerId) {
		this.ledgerId = ledgerId;
	}

	public String getFileType() {
		return fileType;
	}

	public void setFileType(String fileType) {
		this.fileType = fileType;
	}

	public String getLogNumber() {
		return logNumber;
	}

	public void setLogNumber(String logNumber) {
		this.logNumber = logNumber;
	}

	public Boolean getProjectManagerFlag() {
		return projectManagerFlag;
	}

	public void setProjectManagerFlag(Boolean projectManagerFlag) {
		this.projectManagerFlag = projectManagerFlag;
	}
}
